@@ -26,24 +26,27 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_assistant_archive_export.h"
-#include "./gsb_assistant.h"
-#include "./export_csv.h"
-#include "./gsb_data_archive.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_file.h"
-#include "./gsb_file_save.h"
-#include "./gsb_file_util.h"
-#include "./utils_dates.h"
-#include "./qif.h"
-#include "./utils_str.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./gsb_transactions_list.h"
-#include "./include.h"
+#include "gsb_assistant.h"
+#include "export_csv.h"
+#include "gsb_data_archive.h"
+#include "gsb_data_fyear.h"
+#include "gsb_file.h"
+#include "gsb_file_save.h"
+#include "gsb_file_util.h"
+#include "utils_dates.h"
+#include "qif.h"
+#include "utils_str.h"
+#include "utils.h"
+#include "structures.h"
+#include "gsb_transactions_list.h"
 /*END_INCLUDE*/
 
 
@@ -74,14 +77,14 @@ static GtkWidget *archive_export_combobox = NULL;
 static GtkWidget *archive_export_label_success = NULL;
 
 /*START_STATIC*/
-static  gint gsb_assistant_archive_export_get_selected_archive ( GtkTreeModel *model );
-static  GtkWidget *gsb_assistant_archive_export_page_choose ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_archive_export_page_name ( GtkWidget *assistant );
-static  GtkWidget *gsb_assistant_archive_export_page_succes ( GtkWidget *assistant );
-static  gboolean gsb_assistant_archive_export_toggled ( GtkCellRendererToggle *renderer,
+static gint gsb_assistant_archive_export_get_selected_archive ( GtkTreeModel *model );
+static GtkWidget *gsb_assistant_archive_export_page_choose ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_archive_export_page_name ( GtkWidget *assistant );
+static GtkWidget *gsb_assistant_archive_export_page_succes ( GtkWidget *assistant );
+static gboolean gsb_assistant_archive_export_toggled ( GtkCellRendererToggle *renderer,
 						       gchar *path_string,
 						       GtkWidget *assistant );
-static  gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
+static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 					       gint new_page );
 /*END_STATIC*/
 
@@ -294,7 +297,7 @@ static GtkWidget *gsb_assistant_archive_export_page_name ( GtkWidget *assistant
     /* Layout */
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX ( hbox ),
-			 gtk_label_new ( COLON ( _("Export format") ) ),
+			 gtk_label_new ( _("Export format: ") ),
 			 FALSE, FALSE, 0 );
 
     /* Combo box */
@@ -375,7 +378,7 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 	    /* if we come here, an archive must have been selected,
 	     * so needn't to check */
 	    tmpstr = g_markup_printf_escaped ( 
-                        _("<span size=\"x-large\">Exporting the archive : %s</span>"),
+                        _("<span size=\"x-large\">Exporting the archive: %s</span>"),
                         gsb_data_archive_get_name (archive_number));
 	    gtk_label_set_markup ( GTK_LABEL ( archive_export_label ), tmpstr);
 	    g_free ( tmpstr );
