@@ -25,30 +25,33 @@
  * contains the part to set the configuration of the currencies
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_currency_config.h"
-#include "./dialog.h"
-#include "./gsb_autofunc.h"
-#include "./gsb_automem.h"
-#include "./parametres.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./utils.h"
-#include "./tiers_onglet.h"
-#include "./categories_onglet.h"
-#include "./imputation_budgetaire.h"
-#include "./utils_str.h"
-#include "./structures.h"
-#include "./utils_files.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "dialog.h"
+#include "gsb_autofunc.h"
+#include "gsb_automem.h"
+#include "parametres.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "main.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "tiers_onglet.h"
+#include "categories_onglet.h"
+#include "imputation_budgetaire.h"
+#include "utils_str.h"
+#include "structures.h"
+#include "utils_files.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -136,6 +139,7 @@ struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Asia"), N_("Iraqi Dinar"), N_("Iraq"), "IQD", NULL, TRUE, "IQD.png", 3, 1 },
     { N_("Asia"), N_("Japanese Yen"), N_("Japan"), "JPY", "¥", TRUE, "JPY.png", 0, 1 },
     { N_("Asia"), N_("Jordanian Dinar"), N_("Jordan"), "JOD", NULL, TRUE, "JOD.png", 3, 1 },
+    { N_("Asia"), N_("Kazakhstan Tenge"), N_("Kazakhstan"), "KZT", NULL, TRUE, "KZT.png", 2, 1 },
     { N_("Asia"), N_("Kuwaiti Dinar"), N_("Kuwait"), "KWD", NULL, TRUE, "KWD.png", 3, 1 },
     { N_("Asia"), N_("Lao Kip"), N_("Lao People's Democratic Republic"), "LAK", "₭", TRUE, "LAK.png", 2, 1 },
     { N_("Asia"), N_("Lebanese Pound"), N_("Lebanon"), "LBP", "£", TRUE, "LBP.png", 3, 1 },
@@ -350,7 +354,7 @@ GtkWidget *gsb_currency_config_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, TRUE, TRUE, 0 );
 
     /* Create currency name entry */
-    label = gtk_label_new (COLON(_("Name")));
+    label = gtk_label_new ( _("Name: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
@@ -363,7 +367,7 @@ GtkWidget *gsb_currency_config_create_page ( void )
     g_object_set_data ( G_OBJECT(currency_tree_model), "entry_name", entry );
 
     /* Create Sign entry */
-    label = gtk_label_new (COLON(_("Sign")));
+    label = gtk_label_new ( _("Sign: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
@@ -376,7 +380,7 @@ GtkWidget *gsb_currency_config_create_page ( void )
     g_object_set_data ( G_OBJECT(currency_tree_model), "entry_code", entry );
 
     /* Create ISO code entry */
-    label = gtk_label_new ( COLON(_("ISO code")) );
+    label = gtk_label_new ( _("ISO code: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 2, 3,
@@ -389,7 +393,7 @@ GtkWidget *gsb_currency_config_create_page ( void )
     g_object_set_data ( G_OBJECT(currency_tree_model), "entry_iso_code", entry );
 
     /* Create floating point entry */
-    label = gtk_label_new ( COLON(_("Floating point")) );
+    label = gtk_label_new ( _("Floating point: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 3, 4,
@@ -558,7 +562,7 @@ void gsb_currency_append_currency_to_list ( GtkListStore *model,
     GtkTreeIter iter;
     gchar *string;
 
-    string = g_strconcat( PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
+    string = g_strconcat( GRISBI_PIXMAPS_DIR, C_DIRECTORY_SEPARATOR,
 			  "flags", C_DIRECTORY_SEPARATOR,
 			  gsb_data_currency_get_code_iso4217 (currency_number),
 			  ".png", NULL );
@@ -815,7 +819,7 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     gtk_table_set_col_spacings ( GTK_TABLE ( table ), 5 );
     gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
 
-    label = gtk_label_new (COLON(_("Currency for payees tree")));
+    label = gtk_label_new ( _("Currency for payees tree: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label,
@@ -825,7 +829,7 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     gtk_table_attach ( GTK_TABLE ( table ), combo_devise_totaux_tiers,
                         1, 2, 0, 1, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
-    label = gtk_label_new (COLON(_("Currency for categories tree")));
+    label = gtk_label_new ( _("Currency for categories tree: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label,
@@ -835,7 +839,7 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     gtk_table_attach ( GTK_TABLE ( table ), combo_devise_totaux_categ,
                         1, 2, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
-    label = gtk_label_new (COLON(_("Currency for budgetary lines tree")));
+    label = gtk_label_new ( _("Currency for budgetary lines tree: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label,
@@ -848,7 +852,8 @@ GtkWidget *gsb_currency_config_create_totals_page ( void )
     check_button = gsb_automem_checkbutton_new (
                         _("Add transactions archived in the totals"),
                         &(etat.add_archive_in_total_balance),
-                        G_CALLBACK ( gsb_config_metatree_sort_transactions ), NULL);
+                        G_CALLBACK ( gsb_config_metatree_sort_transactions_changed ),
+                        NULL);
     gtk_table_attach ( GTK_TABLE ( table ), check_button,
                         0, 1, 3, 4, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
@@ -973,7 +978,7 @@ gboolean gsb_currency_config_add_currency ( GtkWidget *button,
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, TRUE, TRUE, 0 );
 
     /* Currency name */
-    label = gtk_label_new (COLON(_("Currency name")));
+    label = gtk_label_new ( _("Currency name: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
@@ -985,7 +990,7 @@ gboolean gsb_currency_config_add_currency ( GtkWidget *button,
     g_object_set_data ( G_OBJECT(model), "entry_name", entry_name );
 
     /* Currency ISO code */
-    label = gtk_label_new (COLON(_("Currency international code")));
+    label = gtk_label_new ( _("Currency international code: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
@@ -996,7 +1001,7 @@ gboolean gsb_currency_config_add_currency ( GtkWidget *button,
     g_object_set_data ( G_OBJECT(model), "entry_iso_code", entry_isocode );
 
     /* Currency usual sign */
-    label = gtk_label_new (COLON(_("Currency sign")));
+    label = gtk_label_new ( _("Currency sign: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 2, 3,
@@ -1007,7 +1012,7 @@ gboolean gsb_currency_config_add_currency ( GtkWidget *button,
     g_object_set_data ( G_OBJECT(model), "entry_code", entry_code );
 
     /* Create floating point entry */
-    label = gtk_label_new ( COLON(_("Floating point")) );
+    label = gtk_label_new ( _("Floating point: ") );
     gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
     gtk_label_set_justify ( GTK_LABEL(label), GTK_JUSTIFY_RIGHT );
     gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 3, 4,
@@ -1243,7 +1248,7 @@ void gsb_currency_config_fill_popup_list ( GtkTreeView * tree_view,
 	    GdkPixbuf * pixbuf;
 	    gchar *string;
 
-	    string = g_build_filename ( PIXMAPS_DIR,
+	    string = g_build_filename ( GRISBI_PIXMAPS_DIR,
 					"flags",
 					currency -> flag_filename,
 					NULL );
