@@ -26,27 +26,31 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "gsb_data_transaction.h"
-#include "./balance_estimate_data.h"
-#include "./classement_echeances.h"
-#include "./dialog.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_currency_link.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_payment.h"
-#include "./utils_dates.h"
-#include "./gsb_real.h"
-#include "./utils_str.h"
-#include "./include.h"
-#include "./structures.h"
+#include "bet_data.h"
+#include "classement_echeances.h"
+#include "dialog.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_currency_link.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_payment.h"
+#include "utils_dates.h"
+#include "gsb_real.h"
+#include "utils_str.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 
@@ -101,7 +105,7 @@ typedef struct
 
 /*START_STATIC*/
 static void gsb_data_transaction_delete_all_transactions ( void );
-static  void gsb_data_transaction_free ( struct_transaction *transaction);
+static void gsb_data_transaction_free ( struct_transaction *transaction);
 static gint gsb_data_transaction_get_last_white_number (void);
 static struct_transaction *gsb_data_transaction_get_transaction_by_no ( gint transaction_number );
 static gboolean gsb_data_transaction_save_transaction_pointer ( gpointer transaction );
@@ -763,8 +767,8 @@ gsb_real gsb_data_transaction_get_adjusted_amount_for_currency ( gint transactio
     if ( transaction -> currency_number == return_currency_number )
         return gsb_real_adjust_exponent  ( transaction -> transaction_amount,
 					   return_exponent );
-//~ printf ("get_adjusted_amount transaction_number = %d transaction -> currency_number = %d return_currency_number = %d\n",
-    //~ transaction_number, transaction -> currency_number, return_currency_number);
+/* printf ("get_adjusted_amount transaction_number = %d transaction -> currency_number = %d return_currency_number = %d\n",
+    transaction_number, transaction -> currency_number, return_currency_number); */
     /* now we can adjust the amount */
 	/* the exchange is saved in the transaction itself */
     if ( transaction -> exchange_rate.mantissa )
@@ -1545,25 +1549,17 @@ gboolean gsb_data_transaction_set_archive_number ( gint transaction_number,
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
     if ( !transaction )
-    return FALSE;
+        return FALSE;
 
-    /* we choose to set or not the transaction to the transactions_list
-     * if the archive_number of the transaction is 0 for now, it's already in that list,
+    /* if the archive_number of the transaction is 0 for now, it's already in that list,
      * so we mustn't add it,
-     * else, according to the new value, we remove it or append it */
-    if (transaction -> archive_number)
-    {
-    /* that transaction was an archive, so it's only in the complete_transactions_list */
-    if  (!archive_number)
-        /* the transaction was an archive, and we transform it as non archived transaction,
-         * so we add it into the transactions_list */
-        transactions_list = g_slist_append ( transactions_list, transaction );
-    }
-    else
+     * else, according to the new value, we remove it
+    */
+    if ( !transaction -> archive_number )
     {
         /* the transaction was not an archive, so it's into the 2 lists,
          * if we transform it as an archive, we remove it from the transactions_list */
-        if (archive_number)
+        if ( archive_number )
             transactions_list = g_slist_remove ( transactions_list, transaction );
     }
 
@@ -2164,6 +2160,9 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
         target_transaction -> archive_number = 0;
     }
 
+    /* make the archive_number */
+    target_transaction -> archive_number = 0;
+
     /* make a new copy of all the pointers */
     if ( target_transaction -> notes)
 	target_transaction -> notes = my_strdup ( source_transaction -> notes );
@@ -2200,6 +2199,8 @@ static void gsb_data_transaction_free ( struct_transaction *transaction)
         g_free ( transaction -> notes );
     if ( transaction -> voucher )
         g_free ( transaction -> voucher );
+    if ( transaction -> bank_references )
+        g_free ( transaction -> bank_references );
     if ( transaction -> date )
         g_date_free ( transaction -> date );
     if ( transaction -> value_date )
@@ -2310,10 +2311,8 @@ gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
 
     gsb_data_transaction_free (transaction);
 
-#ifdef ENABLE_BALANCE_ESTIMATE
     /* force the update module budget */
-    bet_data_set_maj ( transaction -> account_number, BET_MAJ_ESTIMATE );
-#endif /* ENABLE_BALANCE_ESTIMATE */
+    gsb_data_account_set_bet_maj ( transaction -> account_number, BET_MAJ_ALL );
 
     return TRUE;
 }
@@ -2572,7 +2571,7 @@ gint gsb_data_transaction_get_white_line ( gint transaction_number )
  * \return the number of the transaction if one is found, FALSE if none found, so can use it
  * */
 gint gsb_data_transaction_check_content_payment ( gint payment_number,
-                        gint number )
+                        const gchar *number )
 {
     GSList *tmp_list;
 
@@ -2593,8 +2592,11 @@ gint gsb_data_transaction_check_content_payment ( gint payment_number,
 
 	if ( transaction -> method_of_payment_number == payment_number
 	     &&
-	     utils_str_atoi (transaction -> method_of_payment_content) == number )
+         transaction -> method_of_payment_content
+         &&
+	     g_ascii_strcasecmp (transaction -> method_of_payment_content, number ) == 0 )
 	    return transaction -> transaction_number;
+
 	tmp_list = tmp_list -> next;
     }
     return FALSE;
@@ -2619,8 +2621,13 @@ GSList *gsb_data_transaction_get_transactions_list_by_date ( void )
     else
         list_tmp = g_slist_copy ( transactions_list );
 
-    list_tmp = g_slist_sort (list_tmp, 
+    if ( etat.metatree_sort_transactions == 1 )
+        list_tmp = g_slist_sort (list_tmp,
                         (GCompareFunc) classement_sliste_transactions_par_date );
+    else
+        list_tmp = g_slist_sort (list_tmp,
+                        (GCompareFunc) classement_sliste_transactions_par_date_decroissante );
+
     return list_tmp;
 }
 
@@ -2688,6 +2695,30 @@ gsb_real gsb_data_transaction_get_last_transaction_with_div_sub_div (
 }
 
 
+/**
+ * get floating point of the currency of the transaction given
+ *
+ * \param transaction_number the number of the transaction
+ *
+ * \return the floating_point of currency number of the transaction
+ * */
+gint gsb_data_transaction_get_currency_floating_point ( gint transaction_number )
+{
+    struct_transaction *transaction;
+    gint floating_point;
+
+    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
+
+    if ( !transaction )
+        return -1;
+    else
+    {
+        floating_point = gsb_data_currency_get_floating_point ( transaction -> currency_number );
+        return floating_point;
+    }
+}
+
+
 /**
  *
  *
