@@ -21,57 +21,59 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 #include <time.h>
 
 #ifdef _WIN32
-#	ifdef _MSC_VER
+#	if defined(_MSC_VER) || defined(_MINGW)
 #		include <realpath.h>
 #	else
 #		include <stdlibx.h> // For realpath()
-#	endif//_MSC_VER
-#endif//_WIN32
+#	endif /*_MSC_VER */
+#endif /* _WIN32 */
 
 /*START_INCLUDE*/
 #include "gsb_file.h"
-#include "./menu.h"
-#include "./utils.h"
-#include "./fenetre_principale.h"
-#include "./dialog.h"
-#include "./utils_file_selection.h"
-#include "./gsb_account_property.h"
-#include "./gsb_assistant_account.h"
-#include "./gsb_assistant_file.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_file_load.h"
-#include "./gsb_file_save.h"
-#include "./gsb_file_util.h"
-#include "./navigation.h"
-#include "./accueil.h"
-#include "./gsb_real.h"
-#include "./gsb_status.h"
-#include "./gsb_transactions_list.h"
-#include "./traitement_variables.h"
-#include "./main.h"
-#include "./utils_str.h"
-#include "./parametres.h"
-#include "./affichage_liste.h"
-#include "./transaction_list.h"
-#include "./utils_files.h"
-#include "./utils_str.h"
-#include "./fenetre_principale.h"
-#include "./include.h"
-#include "./structures.h"
-#include "./erreur.h"
+#include "menu.h"
+#include "utils.h"
+#include "fenetre_principale.h"
+#include "dialog.h"
+#include "utils_file_selection.h"
+#include "gsb_account_property.h"
+#include "gsb_assistant_account.h"
+#include "gsb_assistant_file.h"
+#include "gsb_data_account.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_file_config.h"
+#include "gsb_file_load.h"
+#include "gsb_file_save.h"
+#include "gsb_file_util.h"
+#include "navigation.h"
+#include "accueil.h"
+#include "gsb_real.h"
+#include "gsb_status.h"
+#include "gsb_transactions_list.h"
+#include "traitement_variables.h"
+#include "main.h"
+#include "utils_str.h"
+#include "parametres.h"
+#include "affichage_liste.h"
+#include "transaction_list.h"
+#include "utils_files.h"
+#include "structures.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static void gsb_file_append_name_to_opened_list ( gchar * path_fichier );
 static gboolean gsb_file_automatic_backup ( gpointer null );
-static  gchar *gsb_file_dialog_ask_name ( void );
-static  gint gsb_file_dialog_save ( void );
+static gchar *gsb_file_dialog_ask_name ( void );
+static gint gsb_file_dialog_save ( void );
 static gboolean gsb_file_save_backup ( void );
 static gboolean gsb_file_save_file ( gint origine );
 static void gsb_file_save_remove_old_file ( gchar *filename );
@@ -89,8 +91,6 @@ gint id_timeout = 0;
 
 /*START_EXTERN*/
 extern gchar *copy_old_filename;
-extern gchar *initial_file_title;
-extern gchar *initial_holder_title;
 extern GtkWidget *main_hpaned;
 extern GtkWidget *main_vbox;
 extern GtkWidget * navigation_tree_view;
@@ -103,7 +103,6 @@ extern GtkWidget *table_etat;
 extern gchar *titre_fichier;
 extern GtkWidget *tree_view_vbox;
 extern GtkWidget *window;
-extern GtkWidget *window_vbox_principale;
 /*END_EXTERN*/
 
 
@@ -167,6 +166,7 @@ gboolean gsb_file_new_finish ( void )
  */
 void gsb_file_new_gui ( void )
 {
+    GtkWidget *window_vbox_principale;
     GtkWidget * tree_view_widget;
 
     /* dégrise les menus nécessaire */
@@ -177,8 +177,8 @@ void gsb_file_new_gui ( void )
 
     /* Create main widget. */
     gsb_status_message ( _("Creating main window"));
-    gtk_box_pack_start ( GTK_BOX ( window_vbox_principale), create_main_widget(),
-                        TRUE, TRUE, 0 );
+    window_vbox_principale = g_object_get_data ( G_OBJECT ( window ), "window_vbox_principale" );
+    gtk_box_pack_start ( GTK_BOX ( window_vbox_principale), create_main_widget(), TRUE, TRUE, 0 );
 
     /* create the model */
     if (!transaction_list_create ())
@@ -202,33 +202,6 @@ void gsb_file_new_gui ( void )
     /* Display accounts in menus */
     gsb_menu_update_accounts_in_menus ();
 
-    /* Initialisation du titre pour grisbi */
-    if (titre_fichier && strlen (titre_fichier) )
-        g_free (titre_fichier);
-
-    switch ( etat.display_grisbi_title )
-    {
-        case GSB_ACCOUNTS_TITLE:
-            titre_fichier = my_strdup ( initial_file_title );
-        break;
-        case GSB_ACCOUNT_HOLDER:
-            if ( initial_holder_title && strlen ( initial_holder_title ) )
-                titre_fichier = my_strdup ( initial_holder_title );
-            else
-            {
-                etat.display_grisbi_title = GSB_ACCOUNTS_TITLE;
-                titre_fichier = my_strdup ( initial_file_title );
-            }
-        break;
-        case GSB_ACCOUNTS_FILE:
-            titre_fichier = my_strdup ( nom_fichier_comptes );
-        break;
-    }
-
-    /* Affiche le nom du fichier de comptes dans le titre de la fenetre */
-    gsb_file_update_window_title();
-    gsb_main_page_update_homepage_title ( titre_fichier );
-
     gtk_notebook_set_current_page ( GTK_NOTEBOOK( notebook_general ), GSB_HOME_PAGE );
 
     gtk_widget_show ( notebook_general );
@@ -275,9 +248,10 @@ gboolean gsb_file_open_menu ( void )
 	    if ( gsb_file_close() )
 	    {
 		gtk_widget_hide ( selection_fichier );
-		nom_fichier_comptes = file_selection_get_filename ( GTK_FILE_CHOOSER ( selection_fichier ) ) ;
-		gsb_file_update_last_path (file_selection_get_last_directory ( GTK_FILE_CHOOSER ( selection_fichier),
-									       TRUE ));
+		nom_fichier_comptes = file_selection_get_filename ( GTK_FILE_CHOOSER ( selection_fichier ) );
+        gsb_file_update_last_path ( file_selection_get_last_directory (
+                        GTK_FILE_CHOOSER ( selection_fichier),
+                        TRUE ) );
 		gsb_file_open_file (nom_fichier_comptes);
 	    }
 	    break;
@@ -299,6 +273,7 @@ gboolean gsb_file_open_menu ( void )
  * */
 void gsb_file_update_last_path ( const gchar *last_path )
 {
+devel_debug ( last_path );
     if (last_path
 	&&
 	strlen (last_path))
@@ -343,8 +318,12 @@ const gchar *gsb_file_get_backup_path ( void )
  * */
 void gsb_file_set_backup_path ( const gchar *path )
 {
-    backup_path = my_strdup (path);
-    if ( ! g_file_test ( path, G_FILE_TEST_EXISTS ) )
+    if ( path == NULL || strlen ( path ) == 0 )
+        backup_path = my_strdup ( C_PATH_DATA_FILES );
+    else
+        backup_path = my_strdup ( path );
+
+    if ( !g_file_test ( path, G_FILE_TEST_EXISTS ) )
     {
         utils_files_create_XDG_dir ( );
     }
@@ -406,7 +385,10 @@ gboolean gsb_file_open_file ( gchar *filename )
         /* the file has been opened succesfully */
         /* we make a backup if necessary */
         if ( conf.sauvegarde_demarrage )
-            gsb_file_save_backup();
+        {
+            gsb_file_save_backup ();
+            etat.modification_fichier = FALSE;
+        }
     }
     else
     {
@@ -492,6 +474,9 @@ gboolean gsb_file_open_file ( gchar *filename )
 	list_tmp = list_tmp -> next;
     }
 
+    /* set Grisbi title */
+    gsb_main_set_grisbi_title ( -1 );
+
     /* update the main page */
     mise_a_jour_accueil (TRUE);
 
@@ -619,7 +604,7 @@ gboolean gsb_file_save_file ( gint origine )
 	/* update variables */
 	etat.fichier_deja_ouvert = 0;
     modification_fichier ( FALSE );
-	gsb_file_update_window_title ();
+	gsb_main_set_grisbi_title ( gsb_gui_navigation_get_current_account ( ) );
 	gsb_file_append_name_to_opened_list ( nom_fichier_comptes );
     }
 
@@ -724,15 +709,9 @@ gboolean gsb_file_automatic_backup_start ( GtkWidget *checkbutton,
     if (conf.make_backup_every_minutes
 	&&
 	conf.make_backup_nb_minutes )
-#if GLIB_CHECK_VERSION(2,14,0)
 	id_timeout = g_timeout_add_seconds ( conf.make_backup_nb_minutes * 60,
 					     (GSourceFunc) (gsb_file_automatic_backup),
 					     NULL );
-#else
-	id_timeout = g_timeout_add ( conf.make_backup_nb_minutes * 60000,
-				     (GSourceFunc) (gsb_file_automatic_backup),
-				     NULL );
-#endif
     return FALSE;
 }
 
@@ -758,15 +737,9 @@ gboolean gsb_file_automatic_backup_change_time ( GtkWidget *spinbutton,
 
     /* set a new timeout only if there is an interval */
     if (conf.make_backup_nb_minutes)
-#if GLIB_CHECK_VERSION(2,14,0)
 	id_timeout = g_timeout_add_seconds ( conf.make_backup_nb_minutes * 60,
 					     (GSourceFunc) (gsb_file_automatic_backup),
 					     NULL );
-#else
-	id_timeout = g_timeout_add ( conf.make_backup_nb_minutes * 60000,
-				     (GSourceFunc) (gsb_file_automatic_backup),
-				     NULL );
-#endif
 
     return FALSE;
 }
@@ -925,9 +898,11 @@ static gchar *gsb_file_dialog_ask_name ( void )
 
     if ( ! nom_fichier_comptes )
     {
-        gchar* tmpstr = g_strconcat ( titre_fichier, ".gsb", NULL );
-        gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ), tmpstr);
-        g_free ( tmpstr );
+        gchar* tmp_str;
+
+        tmp_str = g_strconcat ( titre_fichier, ".gsb", NULL );
+        gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ), tmp_str);
+        g_free ( tmp_str );
     }
     else
 	gtk_file_chooser_select_filename ( GTK_FILE_CHOOSER (dialog), nom_fichier_comptes );
@@ -1002,7 +977,7 @@ gboolean gsb_file_close ( void )
  	    init_variables ();
         gsb_account_property_clear_config ( );
 
-	    gsb_file_update_window_title();
+        gsb_main_set_grisbi_title ( -1 );
 
 	    menus_sensitifs ( FALSE );
 
@@ -1017,38 +992,6 @@ gboolean gsb_file_close ( void )
 }
 
 
-/**
- * set/update the name of the file on the title of the window
- *
- * \param
- *
- * \return
- * */
-void gsb_file_update_window_title ( void )
-{
-    gchar *titre = NULL;
-
-    devel_debug ( "gsb_file_update_window_title" );
-
-    if ( titre_fichier && strlen ( titre_fichier ) )
-        titre = g_strdup ( titre_fichier );
-    else
-    {
-        if ( nom_fichier_comptes )
-            titre = g_path_get_basename ( nom_fichier_comptes );
-        else
-            titre = g_strconcat ( "<", _("unnamed"), ">", NULL );
-    }
-
-    titre = g_strconcat ( titre, " - ", _("Grisbi"), NULL );
-    gtk_window_set_title ( GTK_WINDOW ( window ), titre );
-
-    if ( titre && strlen ( titre ) > 0 )
-        g_free ( titre );
-}
-
-
-
 /**
  * append a new name to the list of recently opened file
  *
@@ -1063,8 +1006,7 @@ void gsb_file_append_name_to_opened_list ( gchar * path_fichier )
 
     devel_debug (path_fichier);
 
-    if ( !nb_max_derniers_fichiers_ouverts ||
-	 !path_fichier)
+    if ( !path_fichier )
         return;
 
     if ( nb_derniers_fichiers_ouverts < 0 )
@@ -1089,53 +1031,56 @@ void gsb_file_append_name_to_opened_list ( gchar * path_fichier )
      * noms */
     position = 0;
 
-    for ( i = 0; i < nb_derniers_fichiers_ouverts; i++ )
-    {
-        if ( !strcmp ( real_name, tab_noms_derniers_fichiers_ouverts[i] ))
-        {
-            /* 	si ce fichier est déjà le dernier ouvert, on laisse tomber */
-            if ( !i )
-                return;
-
-            position = i;
-        }
-    }
-
-    efface_derniers_fichiers_ouverts ( );
-
-    if ( position )
-    {
-        /* le fichier a été trouvé, on fait juste une rotation */
-        for ( i = position; i > 0 ; i-- )
-            tab_noms_derniers_fichiers_ouverts[i] = tab_noms_derniers_fichiers_ouverts[i-1];
-        if ( real_name )
-            tab_noms_derniers_fichiers_ouverts[0] = my_strdup ( real_name );
-        else
-            tab_noms_derniers_fichiers_ouverts[0] = my_strdup ( "<no file>" );
-
-        affiche_derniers_fichiers_ouverts ( );
-
-        return;
-    }
-
-    /* le fichier est nouveau, on décale tout d'un cran et on met le nouveau à 0 */
-
-    /* si on est déjà au max, c'est juste un décalage avec perte du dernier */
-    /* on garde le ptit dernier dans le cas contraire */
-
     if ( nb_derniers_fichiers_ouverts )
-	dernier = tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1];
-    else
-	dernier = NULL;
+    {
+        for ( i = 0; i < nb_derniers_fichiers_ouverts; i++ )
+        {
+            if ( !strcmp ( real_name, tab_noms_derniers_fichiers_ouverts[i] ) )
+            {
+                /* 	si ce fichier est déjà le dernier ouvert, on laisse tomber */
+                if ( !i )
+                {
+                    g_free ( real_name );
+                    return;
+                }
 
-    for ( i= nb_derniers_fichiers_ouverts - 1 ; i>0 ; i-- )
-	tab_noms_derniers_fichiers_ouverts[i] = tab_noms_derniers_fichiers_ouverts[i-1];
+                position = i;
+            }
+        }
+
+        efface_derniers_fichiers_ouverts ( );
+
+        if ( position )
+        {
+            /* le fichier a été trouvé, on fait juste une rotation */
+            for ( i = position; i > 0 ; i-- )
+                tab_noms_derniers_fichiers_ouverts[i] = tab_noms_derniers_fichiers_ouverts[i-1];
+            if ( real_name )
+                tab_noms_derniers_fichiers_ouverts[0] = my_strdup ( real_name );
+            else
+                tab_noms_derniers_fichiers_ouverts[0] = my_strdup ( "<no file>" );
+
+            affiche_derniers_fichiers_ouverts ( );
+            g_free ( real_name );
+
+            return;
+        }
+        /* le fichier est nouveau, on décale tout d'un cran et on met le nouveau à 0 */
+
+        /* si on est déjà au max, c'est juste un décalage avec perte du dernier */
+        /* on garde le ptit dernier dans le cas contraire */
+        dernier = tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1];
+        for ( i = nb_derniers_fichiers_ouverts - 1 ; i > 0 ; i-- )
+            tab_noms_derniers_fichiers_ouverts[i] = tab_noms_derniers_fichiers_ouverts[i-1];
+    }
+    else
+        dernier = NULL;
 
     if ( nb_derniers_fichiers_ouverts < nb_max_derniers_fichiers_ouverts )
     {
-	tab_noms_derniers_fichiers_ouverts = g_realloc ( tab_noms_derniers_fichiers_ouverts,
-						       ( ++nb_derniers_fichiers_ouverts ) * sizeof ( gpointer ));
-	tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1] = dernier;
+        tab_noms_derniers_fichiers_ouverts = g_realloc ( tab_noms_derniers_fichiers_ouverts,
+						    ( ++nb_derniers_fichiers_ouverts ) * sizeof ( gpointer ) );
+        tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1] = dernier;
     }
 
     tab_noms_derniers_fichiers_ouverts[0] = my_strdup ( real_name );
