@@ -27,33 +27,33 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_form_transaction.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_currency_link.h"
-#include "./gsb_data_form.h"
-#include "./gsb_data_mix.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_report.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_form.h"
-#include "./gsb_form_widget.h"
-#include "./gsb_payment_method.h"
-#include "./gsb_real.h"
-#include "./gsb_transactions_list.h"
-#include "./gtk_combofix.h"
-#include "./etats_calculs.h"
-#include "./gsb_data_payment.h"
-#include "./gtk_combofix.h"
-#include "./gsb_data_form.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./structures.h"
-#include "./gsb_form_widget.h"
+#include "etats_calculs.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_currency_link.h"
+#include "gsb_data_form.h"
+#include "gsb_data_mix.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_report.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form.h"
+#include "gsb_form_widget.h"
+#include "gsb_payment_method.h"
+#include "gsb_real.h"
+#include "gsb_transactions_list.h"
+#include "gtk_combofix.h"
+#include "structures.h"
+#include "utils_dates.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -126,7 +126,7 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
         return TRUE;
 
     /* find the last transaction with that payee */
-    if ( etat.automatic_completion_payee )
+    if ( conf.automatic_completion_payee )
     transaction_number = gsb_form_transactions_look_for_last_party ( payee_number,
                         0,
                         account_number );
@@ -169,8 +169,9 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
         &&
         gsb_data_transaction_get_split_of_transaction (transaction_number))
         {
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (form_button_recover_split), TRUE);
-        gtk_widget_show (form_button_recover_split);
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON ( form_button_recover_split ),
+                        conf.automatic_recover_splits );
+            gtk_widget_show ( form_button_recover_split );
         }
     }
     else if ( element -> element_number == TRANSACTION_FORM_TYPE )
@@ -189,10 +190,10 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
         if ( gsb_data_mix_get_amount ( number, TRUE ).mantissa < 0 )
             gsb_payment_method_create_combo_list ( widget,
                                    GSB_PAYMENT_DEBIT,
-                                   account_number, 0 );
+                                   account_number, 0, FALSE );
         else
             gsb_payment_method_create_combo_list ( widget, GSB_PAYMENT_CREDIT, 
-                        account_number, 0 );
+                        account_number, 0, FALSE );
 
         if ( GTK_WIDGET_VISIBLE (widget))
         {
@@ -206,7 +207,7 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
                                 account_number );
 
             /* we show the cheque entry only for transactions */
-            if (gsb_payment_method_set_combobox_history ( widget, number )
+            if (gsb_payment_method_set_combobox_history ( widget, number, TRUE )
                 &&
                 gsb_data_payment_get_show_entry ( number )
                 &&
@@ -276,7 +277,7 @@ gint gsb_form_transactions_look_for_last_party ( gint no_party,
 
     /* if we don't want to complete with a transaction in another account,
      * go away here */
-    if ( etat.limit_completion_to_current_account )
+    if ( conf.limit_completion_to_current_account )
 	return 0;
 
     return last_transaction_with_party_not_in_account;
@@ -349,63 +350,70 @@ GSList *gsb_form_transaction_get_parties_list_from_report ( void )
     /*     check that the party's form exist, else, append -1 and go away */
     if ( gsb_data_form_check_for_value (TRANSACTION_FORM_PARTY))
     {
-	const gchar *string;
+        GtkWidget *combofix;
+        const gchar *string;
 
-	string = gtk_combofix_get_text ( GTK_COMBOFIX ( gsb_form_widget_get_widget (TRANSACTION_FORM_PARTY)));
+        combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
+        if ( GTK_IS_COMBOFIX ( combofix ) )
+            string = gtk_combofix_get_text ( GTK_COMBOFIX ( combofix ) );
+        else
+        {
+            parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( - 1) );
+            return parties_list;
+        }
 
-	if ( strncmp ( string,
-		       _("Report : "),
-		       7 ))
-	    /* the party is not a report, set -1 and go away */
-	    parties_list = g_slist_append (parties_list,
-					   GINT_TO_POINTER (-1));
-	else
-	{
-	    /* it's a report */
+        if ( string == NULL || strlen ( string ) == 0 )
+        {
+            parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( - 1) );
+            return parties_list;
+        }
 
-	    gchar **tab_char;
-	    gint report_number;
+        if ( strncmp ( string, _("Report : "), 7 ) )
+            /* the party is not a report, set -1 and go away */
+            parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( -1 ) );
+        else
+        {
+            /* it's a report */
+            gchar **tab_char;
+            gint report_number;
 
-	    tab_char = g_strsplit ( string,
-				    " : ",
-				    2 );
+            tab_char = g_strsplit ( string, " : ", 2 );
 
-	    report_number = gsb_data_report_get_report_by_name (tab_char[1]);
+            report_number = gsb_data_report_get_report_by_name (tab_char[1]);
 
-	    if (report_number)
-	    {
-		GSList *list_transactions;
-		GSList *list_tmp;
+            if (report_number)
+            {
+            GSList *list_transactions;
+            GSList *list_tmp;
 
-		list_transactions = recupere_opes_etat (report_number);
+            list_transactions = recupere_opes_etat (report_number);
 
-		list_tmp = list_transactions;
+            list_tmp = list_transactions;
 
-		while ( list_tmp )
-		{
-		    gint transaction_number;
+            while ( list_tmp )
+            {
+                gint transaction_number;
 
-		    transaction_number = gsb_data_transaction_get_transaction_number (list_tmp -> data);
+                transaction_number = gsb_data_transaction_get_transaction_number (list_tmp -> data);
 
-		    if ( !g_slist_find ( parties_list,
-					 GINT_TO_POINTER (gsb_data_transaction_get_party_number (transaction_number))))
-			parties_list = g_slist_append ( parties_list,
-							GINT_TO_POINTER ( gsb_data_transaction_get_party_number (transaction_number)));
-		    list_tmp = list_tmp -> next;
-		}
-		g_slist_free ( list_transactions );
-	    }
-	    else
-		/* the report was not found, set -1 */
-		parties_list = g_slist_append (parties_list,
-					       GINT_TO_POINTER (-1));
-	    g_strfreev ( tab_char );
-	}
+                if ( !g_slist_find ( parties_list,
+                         GINT_TO_POINTER (gsb_data_transaction_get_party_number (transaction_number))))
+                parties_list = g_slist_append ( parties_list,
+                                GINT_TO_POINTER ( gsb_data_transaction_get_party_number (transaction_number)));
+                list_tmp = list_tmp -> next;
+            }
+            g_slist_free ( list_transactions );
+            }
+            else
+            /* the report was not found, set -1 */
+            parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( -1 ) );
+            g_strfreev ( tab_char );
+        }
     }
     else
 	/* no party so not a report */
-	parties_list = g_slist_append ( parties_list,
-					GINT_TO_POINTER (-1));
+	parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( - 1) );
+
     return parties_list;
 }
 
@@ -427,8 +435,11 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
                         gint new_transaction,
                         gint account_transfer )
 {
+    GDate *contra_value_date = NULL;
+    const gchar *contra_transaction_content = NULL;
     gint contra_transaction_number;
     gint contra_mother_number = 0;
+    gint contra_marked_transaction = 0;
     GtkWidget *contra_payment_button;
 
     g_return_val_if_fail ( account_transfer >= 0, -1 );
@@ -438,42 +449,56 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
      * we delete the contra-transaction and it's the same as a new transfer */
     if ( !new_transaction )
     {
-	/* it's a modification of a transaction */
+        /* it's a modification of a transaction */
 
-	/* as we will do a transfer, the category number is null */
-	gsb_data_transaction_set_category_number ( transaction_number, 0 );
-	gsb_data_transaction_set_sub_category_number ( transaction_number, 0 );
-	contra_transaction_number = gsb_data_transaction_get_contra_transaction_number (
-                        transaction_number);
+        /* as we will do a transfer, the category number is null */
+        gsb_data_transaction_set_category_number ( transaction_number, 0 );
+        gsb_data_transaction_set_sub_category_number ( transaction_number, 0 );
+        contra_transaction_number = gsb_data_transaction_get_contra_transaction_number (
+                            transaction_number);
+        if (contra_transaction_number > 0)
+        {
+            const GDate *value_date;
 
-	if (contra_transaction_number > 0)
-	{
-	    /* the transaction is a transfer */
+            /* the transaction is a transfer */
 
-	    /* if the contra transaction was a child of split, copying/deleting it
-	     * will remove the information of the mother, so we get it here */
-	    contra_mother_number = gsb_data_transaction_get_mother_transaction_number (
-                        contra_transaction_number);
+            /* if the contra transaction was a child of split, copying/deleting it
+             * will remove the information of the mother, so we get it here */
+            contra_mother_number = gsb_data_transaction_get_mother_transaction_number (
+                            contra_transaction_number );
 
-	    /* check if we change the account targe */
-	    if ( gsb_data_transaction_get_contra_transaction_account (
-                        transaction_number) != account_transfer )
-	    {
-            /* it was a transfer and the user changed the target account so we delete
-             * the last contra transaction contra_transaction_transfer has just been set */
+            /* Copying/deleting remove the marked information, so we get it here */
+            contra_marked_transaction = gsb_data_transaction_get_marked_transaction (
+                            contra_transaction_number );
 
-            gsb_data_transaction_set_contra_transaction_number (
-                            contra_transaction_number, 0);
-            gsb_transactions_list_delete_transaction (contra_transaction_number, FALSE);
+            /* Copying/deleting remove the content information, so we get it here */
+            contra_transaction_content = gsb_data_transaction_get_method_of_payment_content (
+                            contra_transaction_number );
+
+            /* Copying/deleting remove the value date, so we get it here */
+            value_date = gsb_data_transaction_get_value_date ( contra_transaction_number );
+            if ( value_date )
+                contra_value_date = gsb_date_copy ( value_date );
+
+
+            /* check if we change the account target */
+            if ( gsb_data_transaction_get_contra_transaction_account (
+                            transaction_number) != account_transfer )
+            {
+                /* it was a transfer and the user changed the target account so we delete
+                 * the last contra transaction contra_transaction_transfer has just been set */
+
+                gsb_data_transaction_set_contra_transaction_number (
+                                contra_transaction_number, 0);
+                gsb_transactions_list_delete_transaction (contra_transaction_number, FALSE);
+                new_transaction = 1;
+            }
+        }
+        else
+        {
+            /* the transaction was not a transfer, so it's the same as a new transaction, to do the contra-transaction */
             new_transaction = 1;
-	    }
-	}
-	else
-	{
-	    /* the transaction was not a transfer, so it's the same as a new transaction, to do the contra-transaction */
-
-	    new_transaction = 1;
-	}
+        }
     }
 
     /* so, now, it's either a new transfer and new_transaction is TRUE,
@@ -481,7 +506,7 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
      * already set */
 
     if ( new_transaction )
-        contra_transaction_number = gsb_data_transaction_new_transaction (account_transfer);
+        contra_transaction_number = gsb_data_transaction_new_transaction ( account_transfer );
 
     gsb_data_transaction_copy_transaction ( transaction_number,
 					    contra_transaction_number, new_transaction );
@@ -493,6 +518,18 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
     gsb_data_transaction_set_mother_transaction_number ( contra_transaction_number,
 							 contra_mother_number );
 
+    /* If this is not a new transaction it restores the marked statement */
+    gsb_data_transaction_set_marked_transaction ( contra_transaction_number,
+                        contra_marked_transaction );
+
+    /* If this is not a new transaction it restores the value date */
+    if ( contra_value_date )
+    {
+		gsb_data_transaction_set_value_date ( contra_transaction_number, contra_value_date );
+
+		g_date_free ( contra_value_date );
+	}
+
     /* we have to change the amount by the opposite */
     gsb_data_transaction_set_amount (contra_transaction_number,
 				     gsb_real_opposite (gsb_data_transaction_get_amount (transaction_number)));
@@ -511,6 +548,11 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
 	gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
 							    gsb_payment_method_get_selected_number (contra_payment_button));
 
+    /* set the content of the contra-method of paiement if it is not a new transaction */
+    if ( !new_transaction )
+        gsb_data_transaction_set_method_of_payment_content ( contra_transaction_number,
+                        contra_transaction_content );
+
     /* set the link between the transactions */
     gsb_data_transaction_set_contra_transaction_number ( transaction_number,
 							 contra_transaction_number);
@@ -527,7 +569,6 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
 }
 
 
-
 /**
  * callback called when the user click on the 'change' button in the form
  * show a popup to modify the values
@@ -596,6 +637,7 @@ void gsb_form_transaction_currency_changed ( GtkWidget *widget, gpointer null )
     gint account_number;
     gint currency_number;
     gint account_currency_number;
+    gint transaction_number;
     gint link_number;
 
     account_number = gsb_form_get_account_number ( );
@@ -603,6 +645,10 @@ void gsb_form_transaction_currency_changed ( GtkWidget *widget, gpointer null )
 
     account_currency_number = gsb_data_account_get_currency ( account_number );
 
+    transaction_number = GPOINTER_TO_INT ( g_object_get_data (
+                        G_OBJECT ( gsb_form_get_form_widget ( ) ),
+                        "transaction_number_in_form" ) );
+
     currency_number = gsb_currency_get_currency_from_combobox ( widget );
     if ( account_currency_number == currency_number )
         gtk_widget_hide ( gsb_form_widget_get_widget ( TRANSACTION_FORM_CHANGE ) );
@@ -613,13 +659,7 @@ void gsb_form_transaction_currency_changed ( GtkWidget *widget, gpointer null )
                         currency_number );
     if ( link_number == 0 )
     {
-        gint transaction_number;
-
-        transaction_number = GPOINTER_TO_INT (g_object_get_data (
-                        G_OBJECT ( gsb_form_get_form_widget ( ) ),
-                        "transaction_number_in_form" ));
-
-        if ( gsb_data_transaction_get_marked_transaction ( transaction_number ) == 3 )
+        if ( gsb_data_transaction_get_marked_transaction ( transaction_number ) == OPERATION_RAPPROCHEE )
         {
             gtk_widget_set_sensitive ( widget, FALSE );
             gtk_widget_hide ( gsb_form_widget_get_widget (
@@ -642,6 +682,11 @@ void gsb_form_transaction_currency_changed ( GtkWidget *widget, gpointer null )
                         TRUE );
         }
     }
+    else if ( transaction_number > 0 )
+    {
+        gsb_currency_set_current_exchange ( gsb_data_transaction_get_exchange_rate ( transaction_number ) );
+        gsb_currency_set_current_exchange_fees ( gsb_data_transaction_get_exchange_fees ( transaction_number ) );
+    }
 }
 /* Local Variables: */
 /* c-basic-offset: 4 */
