@@ -21,42 +21,45 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "navigation.h"
-#include "./balance_estimate_data.h"
-#include "./gsb_account_property.h"
-#include "./gsb_calendar.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_import_rule.h"
-#include "./gsb_data_reconcile.h"
-#include "./gsb_data_report.h"
-#include "./utils_dates.h"
-#include "./gsb_file.h"
-#include "./gsb_form.h"
-#include "./gsb_form_scheduler.h"
-#include "./fenetre_principale.h"
-#include "./menu.h"
-#include "./etats_onglet.h"
-#include "./accueil.h"
-#include "./gsb_real.h"
-#include "./gsb_reconcile.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_transactions_list.h"
-#include "./main.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./tiers_onglet.h"
-#include "./categories_onglet.h"
-#include "./imputation_budgetaire.h"
-#include "./transaction_list_select.h"
-#include "./transaction_list_sort.h"
-#include "./utils_str.h"
-#include "./fenetre_principale.h"
-#include "./include.h"
-#include "./erreur.h"
-#include "./structures.h"
+#include "bet_data.h"
+#include "gsb_account_property.h"
+#include "gsb_calendar.h"
+#include "gsb_data_account.h"
+#include "gsb_data_import_rule.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_report.h"
+#include "utils_dates.h"
+#include "gsb_file.h"
+#include "gsb_form.h"
+#include "gsb_form_scheduler.h"
+#include "fenetre_principale.h"
+#include "bet_finance_ui.h"
+#include "menu.h"
+#include "etats_onglet.h"
+#include "accueil.h"
+#include "gsb_real.h"
+#include "gsb_reconcile.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_transactions_list.h"
+#include "main.h"
+#include "traitement_variables.h"
+#include "utils_str.h"
+#include "tiers_onglet.h"
+#include "categories_onglet.h"
+#include "imputation_budgetaire.h"
+#include "transaction_list_select.h"
+#include "transaction_list_sort.h"
+#include "erreur.h"
+#include "structures.h"
+#include "utils.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -64,11 +67,11 @@ static void create_report_list ( GtkTreeModel * model, GtkTreeIter * reports_ite
 static gboolean gsb_gui_navigation_check_key_press ( GtkWidget *tree_view,
                         GdkEventKey *ev,
                         GtkTreeModel *model );
-static  gboolean gsb_gui_navigation_remove_account_iterator ( GtkTreeModel * tree_model, 
+static gboolean gsb_gui_navigation_remove_account_iterator ( GtkTreeModel * tree_model, 
                         GtkTreePath *path, 
                         GtkTreeIter *iter, 
                         gpointer data );
-static  gboolean gsb_gui_navigation_remove_report_iterator ( GtkTreeModel * tree_model, 
+static gboolean gsb_gui_navigation_remove_report_iterator ( GtkTreeModel * tree_model, 
                         GtkTreePath *path, 
                         GtkTreeIter *iter, 
                         gpointer data );
@@ -80,14 +83,14 @@ static void gsb_gui_navigation_set_selection_branch ( GtkTreeSelection * selecti
 static void gsb_gui_navigation_update_account_iter ( GtkTreeModel * model, 
                         GtkTreeIter * account_iter,
                         gint account_number );
-static  gboolean gsb_gui_navigation_update_account_iterator ( GtkTreeModel * tree_model, 
+static gboolean gsb_gui_navigation_update_account_iterator ( GtkTreeModel * tree_model, 
                         GtkTreePath *path, 
                         GtkTreeIter *iter, 
                         gpointer data );
 static void gsb_gui_navigation_update_report_iter ( GtkTreeModel * model, 
                         GtkTreeIter * report_iter,
                         gint report_number );
-static  gboolean gsb_gui_navigation_update_report_iterator ( GtkTreeModel * tree_model, 
+static gboolean gsb_gui_navigation_update_report_iterator ( GtkTreeModel * tree_model, 
                         GtkTreePath *path, 
                         GtkTreeIter *iter, 
                         gpointer data );
@@ -100,12 +103,11 @@ static gboolean navigation_tree_drag_data_get ( GtkTreeDragSource * drag_source,
 
 
 /*START_EXTERN*/
-extern gchar *initial_holder_title;
+extern GtkWidget *account_page;
 extern GtkWidget *label_last_statement;
 extern GtkWidget *menu_import_rules;
 extern gint mise_a_jour_liste_comptes_accueil;
 extern GtkWidget *notebook_general;
-extern gchar *titre_fichier;
 /*END_EXTERN*/
 
 
@@ -240,8 +242,7 @@ GtkWidget * create_navigation_pane ( void )
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( navigation_tree_view ), 
 				  GTK_TREE_VIEW_COLUMN ( column ) );
     /* Account list */
-    tmpstr = g_build_filename ( PIXMAPS_DIR,
-				       "ac_home.png", NULL );
+    tmpstr = g_build_filename ( GRISBI_PIXMAPS_DIR, "ac_home.png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
     g_free ( tmpstr );
     gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &account_iter, NULL);
@@ -258,8 +259,7 @@ GtkWidget * create_navigation_pane ( void )
     create_account_list ( GTK_TREE_MODEL(navigation_model) );
 
     /* Scheduler */
-    tmpstr = g_build_filename( PIXMAPS_DIR,
-			       "scheduler.png", NULL );
+    tmpstr = g_build_filename( GRISBI_PIXMAPS_DIR, "scheduler.png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
     g_free ( tmpstr );
     gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &iter, NULL);
@@ -275,8 +275,7 @@ GtkWidget * create_navigation_pane ( void )
 		       -1 );
 
     /* Payees */
-    tmpstr =  g_build_filename( PIXMAPS_DIR,
-				"payees.png", NULL );
+    tmpstr =  g_build_filename( GRISBI_PIXMAPS_DIR, "payees.png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
     g_free ( tmpstr );
     gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &iter, NULL);
@@ -291,9 +290,24 @@ GtkWidget * create_navigation_pane ( void )
 		       NAVIGATION_SENSITIVE, 1,
 		       -1 );
 
+    /* Credits simulator */
+    tmpstr = g_build_filename( GRISBI_PIXMAPS_DIR, "ac_liability.png", NULL );
+    pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
+    g_free ( tmpstr );
+    gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &iter, NULL);
+    gtk_tree_store_set(GTK_TREE_STORE(navigation_model), &iter, 
+		       NAVIGATION_PIX, pixbuf,
+		       NAVIGATION_TEXT, _("Credits simulator"), 
+		       NAVIGATION_PIX_VISIBLE, TRUE, 
+		       NAVIGATION_FONT, 800,
+		       NAVIGATION_PAGE, GSB_SIMULATOR_PAGE,
+		       NAVIGATION_ACCOUNT, -1,
+		       NAVIGATION_REPORT, -1,
+		       NAVIGATION_SENSITIVE, 1,
+		       -1 );
+
     /* Categories */
-    tmpstr = g_build_filename( PIXMAPS_DIR,
-			       "categories.png", NULL );
+    tmpstr = g_build_filename( GRISBI_PIXMAPS_DIR, "categories.png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
     g_free ( tmpstr );
     gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &iter, NULL);
@@ -309,8 +323,7 @@ GtkWidget * create_navigation_pane ( void )
 		       -1 );
 
     /* Budgetary lines */
-    tmpstr = g_build_filename( PIXMAPS_DIR,
-			       "budgetary_lines.png", NULL );
+    tmpstr = g_build_filename( GRISBI_PIXMAPS_DIR, "budgetary_lines.png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
     g_free ( tmpstr );
     gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &iter, NULL);
@@ -326,8 +339,7 @@ GtkWidget * create_navigation_pane ( void )
 		       -1 );
 
     /* Reports */
-    tmpstr = g_build_filename( PIXMAPS_DIR,
-			       "reports.png", NULL );
+    tmpstr = g_build_filename( GRISBI_PIXMAPS_DIR, "reports.png", NULL );
     pixbuf = gdk_pixbuf_new_from_file ( tmpstr , NULL );
     g_free ( tmpstr );
     gtk_tree_store_append(GTK_TREE_STORE(navigation_model), &reports_iter, NULL);
@@ -959,44 +971,21 @@ gboolean navigation_change_account ( gint *no_account )
 
     /* Sensitive menu items if something is selected. */
     if ( gsb_data_account_get_current_transaction_number ( new_account ) == -1 )
-    {
-	gsb_menu_transaction_operations_set_sensitive ( FALSE );
-    }
+        gsb_menu_transaction_operations_set_sensitive ( FALSE );
     else
-    {
-	gsb_menu_transaction_operations_set_sensitive ( TRUE );
-    }
+        gsb_menu_transaction_operations_set_sensitive ( TRUE );
 
     /* show or hide the rules button in toolbar */
     if ( gsb_data_import_rule_account_has_rule ( new_account ) )
-	gtk_widget_show ( menu_import_rules );
+        gtk_widget_show ( menu_import_rules );
     else
-	gtk_widget_hide ( menu_import_rules );
+        gtk_widget_hide ( menu_import_rules );
 
     /* Update the title of the file if needed */
-    if ( etat.display_grisbi_title == GSB_ACCOUNT_HOLDER )
-    {
-        gchar * tmpstr;
+    if ( conf.display_grisbi_title == GSB_ACCOUNT_HOLDER )
+        gsb_main_set_grisbi_title ( new_account );
 
-        if (titre_fichier && strlen (titre_fichier) )
-            g_free (titre_fichier);
-
-        tmpstr = my_strdup ( gsb_data_account_get_holder_name ( new_account ) );
-        if ( tmpstr && strlen (tmpstr) > 0 )
-        {
-            titre_fichier = g_strdup ( tmpstr );
-            g_free ( tmpstr );
-        }
-        else
-            titre_fichier = g_strdup ( initial_holder_title );
-
-        gsb_main_page_update_homepage_title ( titre_fichier );
-        gsb_file_update_window_title ( );
-    }
-
-#ifdef ENABLE_BALANCE_ESTIMATE
     bet_data_select_bet_pages ( new_account );
-#endif /* ENABLE_BALANCE_ESTIMATE */
 
     /* unset the last date written */
     gsb_date_free_last_date ();
@@ -1018,14 +1007,15 @@ void gsb_navigation_update_statement_label ( gint account_number )
     gchar* tmp_str;
     gchar* tmp_str1;
     gchar* tmp_str2;
+    gsb_real amount;
 
     reconcile_number = gsb_data_reconcile_get_account_last_number ( account_number );
+    amount = gsb_data_account_get_marked_balance ( account_number );
     if ( reconcile_number )
     {
         tmp_str1 = gsb_format_gdate ( gsb_data_reconcile_get_final_date (
                                             reconcile_number ) );
-        tmp_str2 = gsb_real_get_string_with_currency (
-                        gsb_data_account_get_marked_balance ( account_number ),
+        tmp_str2 = gsb_real_get_string_with_currency ( amount,
                         gsb_data_account_get_currency ( account_number ), TRUE );
         
         tmp_str = g_strconcat ( _("Last statement: "), tmp_str1, " - ",
@@ -1035,6 +1025,17 @@ void gsb_navigation_update_statement_label ( gint account_number )
         g_free ( tmp_str1 );
         g_free ( tmp_str2 );
     }
+    else if ( amount.mantissa != 0 )
+    {
+        tmp_str2 = gsb_real_get_string_with_currency (amount,
+                        gsb_data_account_get_currency ( account_number ), TRUE );
+        
+        tmp_str = g_strconcat ( _("Last statement: none"), " - ",
+                               _("Reconciled balance: "), tmp_str2, NULL );
+        gtk_label_set_text ( GTK_LABEL ( label_last_statement ), tmp_str);
+        g_free ( tmp_str );
+        g_free ( tmp_str2 );
+    }
     else
         gtk_label_set_text ( GTK_LABEL ( label_last_statement ),
                                             _("Last statement: none") );
@@ -1096,7 +1097,6 @@ void gsb_gui_navigation_remove_account ( gint account_number )
 gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
                         GtkTreeModel *model )
 {
-    GtkWidget * account_notebook;
     gint account_number, page_number;
     gint report_number;
     gchar * title = NULL;
@@ -1111,6 +1111,7 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
     {
         gsb_gui_sensitive_menu_item ( "EditMenu", "NewTransaction", NULL, FALSE );
         gsb_gui_sensitive_menu_item ( "EditMenu", "RemoveAccount", NULL, FALSE );
+        menus_view_sensitifs ( FALSE );
     }
 
     if ( page_number != GSB_SCHEDULER_PAGE ) 
@@ -1123,26 +1124,16 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 	case GSB_HOME_PAGE:
 	    notice_debug ("Home page selected");
 
-	    /* set the title */
-	    if ( titre_fichier && strlen ( titre_fichier ) )
-	    {
-            title = g_strconcat ( "Grisbi : " , titre_fichier, NULL );
-	    }
-	    else
-	    {
-            title = g_strconcat ( "Grisbi : " , _("My accounts"), NULL );
-            titre_fichier = g_strdup  ( _("My accounts") );
-	    }
-
+        gsb_gui_sensitive_menu_item ( "ViewMenu", "ShowClosed", NULL, TRUE );
 	    /* what to be done if switch to that page */
-	    mise_a_jour_accueil (FALSE);
-	    gsb_form_set_expander_visible (FALSE,
-					   FALSE );
+	    mise_a_jour_accueil ( FALSE );
+	    gsb_form_set_expander_visible ( FALSE, FALSE );
 	    break;
 
 	case GSB_ACCOUNT_PAGE:
 	    notice_debug ("Account page selected");
 
+        menus_view_sensitifs ( TRUE );
 	    gsb_gui_sensitive_menu_item ( "EditMenu", "RemoveAccount", NULL, TRUE );
 
 	    account_number = gsb_gui_navigation_get_current_account ();
@@ -1160,12 +1151,11 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 	    gsb_menu_update_view_menu ( account_number );
 
 	    /* set the form */
-	    account_notebook = g_object_get_data ( G_OBJECT (notebook_general), "account_notebook" );
-        gsb_gui_on_account_switch_page ( GTK_NOTEBOOK ( account_notebook ),
+        gsb_gui_on_account_switch_page ( GTK_NOTEBOOK ( account_page ),
                         NULL,
-                        gtk_notebook_get_current_page ( GTK_NOTEBOOK ( account_notebook ) ),
+                        gtk_notebook_get_current_page ( GTK_NOTEBOOK ( account_page ) ),
                         NULL );
-	    gsb_form_show ( FALSE );
+	    /* gsb_form_show ( FALSE ); */
 
 	    buffer_last_account = account_number;
 
@@ -1177,6 +1167,7 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 	    /* set the title */
 	    title = g_strdup(_("Scheduled transactions"));
 
+        
 	    /* what to be done if switch to that page */
 	    /* update the list (can do that because short list, so very fast) */
 	    gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
@@ -1185,14 +1176,16 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 	    gsb_scheduler_list_select (gsb_scheduler_list_get_last_scheduled_number ());
 
 	    /* set the form */
-	    gsb_form_set_expander_visible (TRUE,
-					   FALSE );
+	    gsb_form_set_expander_visible (TRUE, FALSE );
 	    gsb_form_scheduler_clean ();
 	    gsb_form_show ( FALSE );
 
 	    /* show the calendar */
 	    gsb_calendar_update ();
 	    gtk_widget_show_all ( scheduler_calendar );
+
+        /* show menu InitwidthCol */
+        gsb_gui_sensitive_menu_item ( "ViewMenu", "InitwidthCol", NULL, TRUE );
 	    break;
 
 	case GSB_PAYEES_PAGE:
@@ -1206,6 +1199,17 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 		payee_fill_tree ();
 	    break;
 
+	case GSB_SIMULATOR_PAGE:
+	    notice_debug ("Credits simulator page selected");
+
+	    /* set the title */
+	    title = g_strdup(_("Credits simulator"));
+
+	    /* what to be done if switch to that page */
+        gsb_form_set_expander_visible (FALSE, FALSE);
+        bet_finance_switch_simulator_page ( );
+	    break;
+
 	case GSB_CATEGORIES_PAGE:
 	    notice_debug ("Category page selected");
 
