@@ -21,29 +21,36 @@
 /*                                                                            */
 /* ************************************************************************** */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
-#ifdef _MSC_VER
+#if defined(_MSC_VER) || defined (_MINGW)
 #include <winnls.h>
 #else
 #include <langinfo.h>
-#endif//_MSC_VER
+#endif /*_MSC_VER */
 
 /*START_INCLUDE*/
 #include "utils_dates.h"
-#include "./dialog.h"
-#include "./gsb_form_widget.h"
-#include "./utils_str.h"
-#include "./gsb_calendar_entry.h"
+#include "dialog.h"
+#include "gsb_calendar_entry.h"
+#include "gsb_form_widget.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static gchar **split_unique_datefield ( gchar * string, gchar date_tokens [] );
+static gchar **split_unique_datefield ( gchar * string, gchar **date_tokens );
 /*END_STATIC*/
 
 
 /*START_EXTERN*/
 /*END_EXTERN*/
 
+/* format pour les dates */
+static gchar *format = NULL;
 
 /* save of the last date entried */
 static gchar *last_date = NULL;
@@ -66,12 +73,14 @@ gchar *gsb_date_today ( void )
 {
     if (!last_date)
     {
-    GDate *date;
-    gchar date_str[SIZEOF_FORMATTED_STRING_DATE];
+        GDate *date;
+        gchar *date_string;
 
-    date = gdate_today();
-    g_date_strftime ( date_str, SIZEOF_FORMATTED_STRING_DATE, "%x", date );
-    gsb_date_set_last_date (date_str);
+        date = gdate_today ( );
+        date_string = gsb_format_gdate ( date );
+        gsb_date_set_last_date ( date_string );
+        g_free ( date_string );
+        g_date_free ( date );
     }
     return (last_date);
 }
@@ -137,14 +146,36 @@ GDate *gsb_date_tomorrow ( void )
 {
     GDate *date;
 
-    date = g_date_new ( );
-    g_date_set_time_t (  date, time ( NULL ) );
+    date = gdate_today ( );
     g_date_add_days ( date, 1);
 
     return ( date );
 }
 
 
+/**
+ * adds one month to a date
+ *
+ * \param date
+ * \param free the init date
+ *
+ * \return a newly allocated GDate which represents the date of the day. 
+ * Use g_date_free to free memory when no more used.
+ * */
+GDate *gsb_date_add_one_month ( GDate *date, gboolean free )
+{
+    GDate *new_date;
+
+    new_date = gsb_date_copy ( date );
+    g_date_add_months ( new_date, 1);
+
+    if ( free )
+        g_date_free ( date );
+
+    return ( new_date );
+}
+
+
 
 /**
  * copy the date given in param
@@ -270,24 +301,28 @@ gboolean gsb_date_check_entry ( GtkWidget *entry )
  *
  * \return NULL if not a date
  */
-gchar **split_unique_datefield ( gchar * string, gchar date_tokens [] )
+gchar **split_unique_datefield ( gchar *string, gchar **date_tokens )
 {
-/*TODO dOm : I add a & before date_tokens to avoid warning. Is is correct ? */
-    gchar ** return_tab = g_new ( gchar *, g_strv_length ( &date_tokens ) + 1 );
-    int size = strlen ( string );
-    gchar * max = string + size;
-    int i = 0;
+    gchar **return_tab;
+    gint size;
+    gchar *max;
+    gint i = 0;
+    gint num_fields = 0;
+
+    num_fields = g_strv_length ( date_tokens );
+    return_tab = g_new ( gchar *, num_fields + 1 );
+    size = strlen ( string );
+    max = string + size;
 
     /* size 1 could be used for example if we write 1 to set 01/mm/yyyy */
     if ( size != 1 && size != 2 && size != 4 && size != 6 && size != 8 )
     {
-    return NULL;
+        return NULL;
     }
 
     for ( i = 0 ; date_tokens [ i ] && string < max; i ++ )
     {
-        if ( size != 8 ||
-             date_tokens [ i ] != 'Y' )
+        if ( size != 8 || strcmp ( date_tokens [ i ], "Y" ) != 0 )
         {
             return_tab [ i ] = g_strndup ( string, 2 );
             string += 2;
@@ -318,78 +353,33 @@ gchar **split_unique_datefield ( gchar * string, gchar date_tokens [] )
 GDate *gsb_parse_date_string ( const gchar *date_string )
 {
     GDate *date;
-    gchar *string, *string_ptr, *format;
+    gchar *string;
+    gchar *string_ptr;
     gchar **tab_date;
-    gchar date_tokens [ 4 ] = { 0, 0, 0, 0 };
-    int num_tokens = 0, num_fields = 0, i, j;
-#ifdef _MSC_VER
-	gchar * sreturn;
-	gchar ** tab_format;
-	int k = 0;
-#endif
+    gchar **date_tokens;
+    gint num_tokens = 3;
+    gint num_fields = 0;
+    gint i;
+    gint j;
 
-    if ( !date_string || !strlen (date_string) )
+    if ( !date_string || !strlen ( date_string ) )
         return NULL;
 
     /* Keep the const gchar in that function */
-    string = g_strdup (date_string);
+    string = g_strdup ( date_string );
+
     /* And keep a pointer to free memory later */
     string_ptr = string;
-    if ( ! strlen ( string ) )
-    {
-        g_free ( string_ptr );
-        return NULL;
-    }
+
+    /* récupère le format des champs date */
+    date_tokens = g_strsplit ( format + 1, "/%", 3 );
+
+    /* delete space char */
     g_strstrip ( string );
 
-    /* Obtain date format tokens to compute order. */
-#ifdef _MSC_VER
-	sreturn = g_strnfill(81,'\0');
-	GetLocaleInfo(GetThreadLocale(), LOCALE_SSHORTDATE, sreturn, 80);
-	g_strcanon (sreturn, "dMy", '.');
-	tab_format = g_strsplit(sreturn, ".", 3);
-	g_free(sreturn);
-	format = "";
-	while (k < 3)
-	{
-		if(!strncmp(tab_format[k], "dd", 2) || !strncmp(tab_format[k], "d", 1))
-			format = g_strconcat(format, "%d", NULL);
-		else if(!strncmp(tab_format[k], "MM", 2) || !strncmp(tab_format[k], "M", 1))
-			format = g_strconcat(format, "%m", NULL);
-		else if(!strncmp(tab_format[k], "yyyy", 4))
-			format = g_strconcat(format, "%Y", NULL);
-		else if(!strncmp(tab_format[k], "yy", 2))
-			format = g_strconcat(format, "%y", NULL);
-		k++;
-	}
-	g_strfreev(tab_format);
-#else
-    format = nl_langinfo ( D_FMT );
-#endif
-
-    while ( * format )
-    {
-        if ( * format == '%' )
-        {
-            switch ( * ++format )
-            {
-            case 'd': case 'm': case 'y': case 'Y':
-                date_tokens [ num_tokens++ ] = *format ;
-                if ( num_tokens > 3 )
-                {
-                    dialogue_error_brain_damage ();
-                }
-            default:
-                break;
-            }
-        }
-        format++;
-    }
-
-    /* TODO: Check that m,d,Yy are present. */
-    
     /* replace all separators by . */
     g_strcanon ( string, "0123456789", '.' );
+
     /* remove the . at the beginning and ending of the string */
     while ( * string == '.' && * string ) string ++;
     while ( string [ strlen ( string ) - 1 ] == '.' && strlen ( string ) ) 
@@ -401,8 +391,10 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
     string = g_strjoinv ( ".", tab_date );
     string_ptr = string;
     g_strfreev ( tab_date );
+
     /* split the parts of the date */
     tab_date = g_strsplit_set ( string, ".", 0 );
+
     /* From here, string is no more used */
     g_free ( string_ptr );
     string = string_ptr = NULL;
@@ -418,8 +410,12 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
     {
         /* there is only 1 field in the date, try to split the number
          * (ie 01042000 gives 01/04/2000) */
-        gchar ** new_tab_date = split_unique_datefield ( tab_date [ 0 ], date_tokens );
+        gchar **new_tab_date;
+
+        new_tab_date = split_unique_datefield ( tab_date [0], date_tokens );
+
         g_strfreev ( tab_date );
+
         if ( ! new_tab_date )
             return NULL;
         else
@@ -434,8 +430,9 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
 
     for ( i = 0, j = 0 ; i < num_tokens && j < num_fields ; i ++ )
     {
-        int nvalue = atoi ( tab_date [ j ] );
-        switch ( date_tokens [ i ] )
+        gint nvalue = atoi ( tab_date [ j ] );
+
+        switch ( date_tokens [ i ][0] )
         {
             case 'm':
             if ( g_date_valid_month ( nvalue ) )
@@ -446,6 +443,7 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
             else
             {
                 g_date_free ( date );
+                g_strfreev ( tab_date );
                 return NULL;
             }
             break;
@@ -458,6 +456,7 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
             else
             {
                 g_date_free ( date );
+                g_strfreev ( tab_date );
                 return NULL;
             }
             break;
@@ -484,22 +483,24 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
             else
             {
                 g_date_free ( date );
+                g_strfreev ( tab_date );
                 return NULL;
             }
             break;
             default:
-                g_printerr ( ">> Unknown format '%c'\n", date_tokens [ i ] );
+                g_printerr ( ">> Unknown format '%s'\n", date_tokens [ i ] );
                 g_date_free ( date );
+                g_strfreev ( tab_date );
                 return NULL;
             break;
         }
     }
     /* comment for random crash. Memory allocation problem in split_unique_datefield () */
-    //~ g_strfreev ( tab_date );
+    g_strfreev ( tab_date );
 
     /* need here to check if the date is valid, else an error occurs when
      * write for example only 31, and the current month has only 30 days... */
-    if ( !g_date_valid (date) )
+    if ( !g_date_valid ( date ) )
     {
         g_date_free ( date );
         return NULL;
@@ -552,9 +553,13 @@ GDate *gsb_parse_date_string_safe ( const gchar *date_string )
  */
 gchar *gsb_format_date ( gint day, gint month, gint year )
 {
-    GDate* date = g_date_new_dmy ( day, month, year );
-    gchar* result = gsb_format_gdate ( date );
+    GDate* date;
+    gchar* result;
+
+    date = g_date_new_dmy ( day, month, year );
+    result = gsb_format_gdate ( date );
     g_date_free ( date );
+
     return result;
 }
 
@@ -571,15 +576,17 @@ gchar *gsb_format_date ( gint day, gint month, gint year )
 gchar *gsb_format_gdate ( const GDate *date )
 {
     gchar retour_str[SIZEOF_FORMATTED_STRING_DATE];
+    guint longueur;
 
-    if ( !date || !g_date_valid ( date ))
-    {
-    return my_strdup ( "" );
-    }
+    if ( !date || !g_date_valid ( date ) )
+        return my_strdup ( "" );
 
-    g_date_strftime ( retour_str, SIZEOF_FORMATTED_STRING_DATE, "%x", date );
+    longueur = g_date_strftime ( retour_str, SIZEOF_FORMATTED_STRING_DATE, format, date );
 
-    return my_strdup ( retour_str );
+    if ( longueur == 0 )
+        return my_strdup ( "" );
+    else
+        return g_strndup ( retour_str, longueur );
 }
 
 
@@ -595,15 +602,19 @@ gchar *gsb_format_gdate ( const GDate *date )
 gchar *gsb_format_gdate_safe ( const GDate *date )
 {
     gchar retour_str[SIZEOF_FORMATTED_STRING_DATE];
+    guint longueur;
 
-    if ( !date || !g_date_valid ( date ))
+    if ( !date || !g_date_valid ( date ) )
     {
-    return g_strdup ( "" );
+        return g_strdup ( "" );
     }
 
-    g_date_strftime ( retour_str, SIZEOF_FORMATTED_STRING_DATE, "%m/%d/%Y", date );
+    longueur = g_date_strftime ( retour_str, SIZEOF_FORMATTED_STRING_DATE, "%m/%d/%Y", date );
 
-    return g_strdup ( retour_str );
+    if ( longueur == 0 )
+        return NULL;
+    else
+        return g_strndup ( retour_str, longueur );
 }
 
 
@@ -656,8 +667,10 @@ gchar *gsb_date_get_compiled_time ( void )
 
     date = g_date_new_dmy ( atoi ( tab[1] ), mois, atoi ( tab[2] ) );
     g_strfreev (tab);
+    str = gsb_format_gdate ( date );
+    g_date_free ( date );
 
-    return gsb_format_gdate ( date );
+    return str;
 }
 
 
@@ -676,6 +689,44 @@ GDate *gsb_date_get_last_day_of_month ( const GDate *date )
 
     return tmp_date;
 }
+
+
+/**
+ * returns the format of date.
+ * The returned string should be freed with g_free() when no longer needed.
+ *
+ * \return %d/%m/%Y or %m/%d/%Y 
+ * */
+gchar *gsb_date_get_format_date ( void )
+{
+    return g_strdup ( format );
+}
+
+
+/**
+ * set the format of date.
+ * 
+ * */
+void gsb_date_set_format_date ( const gchar *format_date )
+{
+    if ( format && strlen ( format ) )
+        g_free ( format );
+
+    if ( format_date == NULL )
+        format = NULL;
+    else if ( strcmp ( format_date, "%d/%m/%Y" ) == 0 )
+        format = g_strdup ( "%d/%m/%Y" );
+    else if ( strcmp ( format_date, "%m/%d/%Y" ) == 0 )
+        format = g_strdup ( "%m/%d/%Y" );
+    else
+        format = NULL;
+
+    if ( last_date )
+        g_free ( last_date );
+    last_date = NULL;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
